# T,t:

If token ∈ emphatic_lexicon:
    T → ط
Else if token starts with aspect marker (ta-, tay-):
    T → ت
Else if root ∈ emphatic_roots:
    T → ط
Else:
    T → ت

# S,s

if word_root in emphatic_roots:
    map S → ص
else if word is function morpheme or loanword:
    map S → س
else:
    map S → س


# the separators and numbers not displayed :
82: 7na chi 50->حنا شي


# the 8-> ه :

78: wach kaynin modirat khrin fnfs lmostawa dyal8a->واش كاينين موديراة خرين فنفس الموستاوا ديالغا

79: wach kat3rfi nas imkn t8Dri m3ahom bso8oula->واش كاتعرفيناس يمكن تري معاهوم بسوغولا

